==> haskell-regex-compat-tdfa-0.95.1.4-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat-tdfa
version: 0.95.1.4
id: regex-compat-tdfa-0.95.1.4-6zIgMDw4vQE5T8i66CghqF
key: regex-compat-tdfa-0.95.1.4-6zIgMDw4vQE5T8i66CghqF
license: BSD3
copyright: Copyright (c) Christopher Kuklewicz 2006
           (c) shelarcy 2012
maintainer: shelarcy <shelarcy@gmail.com>
stability: Seems to work, passes a few tests
homepage: http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url: http://hackage.haskell.org/package/regex-compat-tdfa
synopsis: Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.
    .
    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.
    .
    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Text.Regex
abi: 90732bb6e6e81222f615fe1875be1dad
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-compat-tdfa-0.95.1.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/regex-compat-tdfa-0.95.1.4
hs-libraries: HSregex-compat-tdfa-0.95.1.4-6zIgMDw4vQE5T8i66CghqF
depends:
    array-0.5.2.0 base-4.10.1.0
    regex-base-0.93.2-2WymZ6oErYqGB0H6LBWVXT
    regex-tdfa-1.2.3-CHlPHhA7z5QKh4VX6QrcGf
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             regex-base-0.93.2-2WymZ6oErYqGB0H6LBWVXT=26a1e2ecf2b8a4c9538db44096d202ad
             regex-tdfa-1.2.3-CHlPHhA7z5QKh4VX6QrcGf=a83a97ef601ac09093211c7caba46a6b
haddock-interfaces: /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-tdfa-0.95.1.4-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat-tdfa
version: 0.95.1.4
id: regex-compat-tdfa-0.95.1.4-6NeOxaXyKetCHMsVAbDwwF
key: regex-compat-tdfa-0.95.1.4-6NeOxaXyKetCHMsVAbDwwF
license: BSD-3-Clause
copyright: Copyright (c) Christopher Kuklewicz 2006
           (c) shelarcy 2012
maintainer: shelarcy <shelarcy@gmail.com>
author: Christopher Kuklewicz
stability: Seems to work, passes a few tests
homepage: http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url: http://hackage.haskell.org/package/regex-compat-tdfa
synopsis: Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.
    .
    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.
    .
    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.
category: Text
abi: 325e2cf5b67fbbd9d3db8795e3ec0c16
exposed: True
exposed-modules:
    Text.Regex
import-dirs: /usr/lib/ghc-8.4.3/site-local/regex-compat-tdfa-0.95.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/regex-compat-tdfa-0.95.1.4
hs-libraries: HSregex-compat-tdfa-0.95.1.4-6NeOxaXyKetCHMsVAbDwwF
depends:
    array-0.5.2.0 base-4.11.1.0
    regex-base-0.93.2-98bD2PeVUkV8MO804tnXmq
    regex-tdfa-1.2.3-1e6W0u5rRmsDEmJafeJHae
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             regex-base-0.93.2-98bD2PeVUkV8MO804tnXmq=6c4f2802d764f7f5a17e91732661aa5a
             regex-tdfa-1.2.3-1e6W0u5rRmsDEmJafeJHae=e64f7247eeed810d7f79ae6f49e42740
haddock-interfaces: /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
